using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO.Ports;

namespace DeviceApplication4
{
    public partial class Form1 : Form
    {
        private Panel pan;
        private int cX, cY, x, y;
        private SerialPort serial;
        private Boolean lightsOn = false;
        public Form1()
        {
            serial = new SerialPort();
            serial.BaudRate = 19200;
            serial.PortName = "COM6";
            serial.Parity = Parity.None;
            serial.DataBits = 8;
            serial.StopBits = StopBits.One;
            serial.Handshake = Handshake.None;
            serial.WriteTimeout = 100;
            serial.Open();
            pan = new Panel();
            pan.Location = new Point(0, 0);
            x = System.Windows.Forms.Screen.PrimaryScreen.Bounds.Width / 2;
            y = System.Windows.Forms.Screen.PrimaryScreen.Bounds.Width / 2;
            pan.Width = x * 2;
            pan.Height = x * 2;
            this.Controls.Add(pan);
            pan.Paint += new PaintEventHandler(draw);
            cX = x;
            cY = y;
            InitializeComponent();
            pan.MouseDown += mouseDown;
            pan.MouseMove += mouseMove;
            pan.MouseUp += mouseReleased;

        }
        public void draw(object sender, PaintEventArgs e)
        {
            Pen pen = new Pen(Color.Tomato, 2);
            Graphics g = e.Graphics;
            g.DrawLine(pen, x, 0, x, y * 2);
            g.DrawLine(pen, 0, y, x * 2, y);
            g.DrawEllipse(pen, cX - 25, cY - 25, 50, 50);
        }
        public void mouseDown(object sender, MouseEventArgs e)
        {
            int mx = e.X;
            int my = e.Y;
            cX = mx;
            cY = my;
            pan.Refresh();
            sendToCar();
        }
        private void mouseMove(object sender, MouseEventArgs e)
        {
            int mx = e.X;
            int my = e.Y;
            cX = mx;
            cY = my;
            pan.Refresh();
            sendToCar();

        }
        private void mouseReleased(object sender, MouseEventArgs e)
        {
            cX = x;
            cY = y;
            pan.Refresh();
            if (serial.IsOpen)
            {
                serial.Write("sxne");
                serial.Write("syne");
            }

        }
        private byte map(int s)
        {
            int a = (int)Math.Pow((double)((s * 255) / x), (double)1.11);
            if (a > 255) { a = 255; }
            if (a < 0) { a = 0; }
            return (byte)a;
        }
        private void button1_Click(object sender, EventArgs e)
        {
            serial.Close();
            Application.Exit();
        }
        private void sendToCar()
        {
            if (cX < x)
            {
                byte[] data = new byte[4];
                byte b = map(x - cX);
                data[0] = (byte)'s';
                data[1] = (byte)'x';
                data[2] = (byte)'l';
                data[3] = b;
                if (serial.IsOpen)
                {
                    serial.Write(data, 0, 4);
                }
            }
            if (cX > x)
            {
                byte[] data = new byte[4];
                byte b = map(cX - x);
                data[0] = (byte)'s';
                data[1] = (byte)'x';
                data[2] = (byte)'r';
                data[3] = b;
                if (serial.IsOpen)
                {
                    serial.Write(data, 0, 4);
                }
            }
            if (cY < x)
            {
                byte[] data = new byte[4];
                byte b = map(x - cY);
                data[0] = (byte)'s';
                data[1] = (byte)'y';
                data[2] = (byte)'f';
                data[3] = b;
                if (serial.IsOpen)
                {
                    serial.Write(data, 0, 4);
                }
            }
            if (cY > x)
            {
                byte[] data = new byte[4];
                byte b = map(cY - x);
                data[0] = (byte)'s';
                data[1] = (byte)'y';
                data[2] = (byte)'r';
                data[3] = b;
                if (serial.IsOpen)
                {
                    serial.Write(data, 0, 4);
                }
            }
        }

        private void label1_ParentChanged(object sender, EventArgs e)
        {

        }

        private void Lights_Click(object sender, EventArgs e)
        {
            lightsOn = !lightsOn;
            if (serial.IsOpen)
            {
                if (lightsOn)
                {
                    serial.Write("slfo");
                }
                else
                {
                    serial.Write("slfn");
                }
            }
        }

        private void trackBar1_ValueChanged(object sender, EventArgs e)
        {
            byte[] data = new byte[4];
            byte b = (byte)trackBar1.Value;
            data[0] = (byte)'s';
            data[1] = (byte)'s';
            data[2] = (byte)'f';
            data[3] = b;
            if (serial.IsOpen)
            {
                serial.Write(data, 0, 4);
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            if (serial.IsOpen)
            {
                serial.Write("saaa");
            }
        }
    }
}